package gov.usgs.earthquake.nshmp.geo;

import static com.google.common.base.Preconditions.checkArgument;

import java.util.List;

import com.google.common.collect.ForwardingList;

/**
 * Default LocationList implementation backed by an immutable List.
 *
 * @author U.S. Geological Survey
 */
final class RegularLocationList extends ForwardingList<Location> implements LocationList {

  private final List<Location> locations;

  RegularLocationList(List<Location> locations) {
    checkArgument(locations.size() > 0, "Location lists may not by empty");
    this.locations = List.copyOf(locations);
  }

  @Override
  protected List<Location> delegate() {
    return locations;
  }

  @Override
  public boolean equals(Object obj) {
    return super.equals(obj) && (obj instanceof LocationList);
  }

  @Override
  public String toString() {
    return Locations.toString(this);
  }

}
