package gov.usgs.earthquake.nshmp.model;

/**
 * Rupture magnitude description.
 *
 * NSHMs include rupture magnitudes that may be constrained by ways other than a
 * mgnitude-scaling relationship as defined by this class.
 *
 * @author U.S. Geological Survey
 */
public enum MagnitudeNote {

  /**
   * Magnitude override that should be explained in a README in a source model.
   */
  OTHER,

  /**
   * Magnitude override that should be explained in a README in a source model
   * with a hint to not float SINGLE MFD ruptures.
   */
  OTHER_NO_FLOAT,

  /**
   * Inconsistency between geologic and geodetic magnitudes.
   */
  GEODETIC_VARIANT,

  /**
   * Constrained by a historic earthquake magnitude.
   */
  HISTORIC_M_MAX,

  /**
   * Constrained by a regional maximum magnitude.
   */
  REGIONAL_M_MAX,

  /**
   * Constrained by a regional maximum magnitude but indicating not to float
   * ruptures for consistency with prior codes.
   */
  REGIONAL_M_MAX_NO_FLOAT;
}
