package gov.usgs.earthquake.nshmp.tree;

import static com.google.common.base.Preconditions.checkNotNull;
import static gov.usgs.earthquake.nshmp.data.DoubleData.checkWeight;

/**
 * Branch with id and value derived from an enum.
 *
 * @author U.S. Geological Survey
 */
class EnumBranch<E extends Enum<E>, T> implements Branch<T> {

  private final E id;
  private final T value;
  private final double weight;

  public EnumBranch(E id, T value, double weight) {
    this.id = checkNotNull(id);
    this.value = checkNotNull(value);
    this.weight = checkWeight(weight);
  }

  @Override
  public String id() {
    return id.name();
  }

  @Override
  public T value() {
    return value;
  }

  @Override
  public double weight() {
    return weight;
  }

  @Override
  public String toString() {
    return Branch.toString(this);
  }
}
