package gov.usgs.earthquake.nshmp.tree;

import static com.google.common.base.Preconditions.checkNotNull;
import static gov.usgs.earthquake.nshmp.data.DoubleData.checkIsPositiveAndRealOrZero;
import static gov.usgs.earthquake.nshmp.tree.RegularBranch.checkId;

/**
 * Logic group branch.
 *
 * @author U.S. Geological Survey
 */
class GroupBranch<T> implements Branch<T> {

  private final String id;
  private final T value;
  private final double scale;

  GroupBranch(String id, T value, double scale) {
    this.id = checkId(id);
    this.value = checkNotNull(value);
    this.scale = checkIsPositiveAndRealOrZero(scale);
  }

  @Override
  public String id() {
    return id;
  }

  @Override
  public T value() {
    return value;
  }

  @Override
  public double weight() {
    return scale;
  }

  @Override
  public String toString() {
    return Branch.toString(this);
  }
}
