package gov.usgs.earthquake.nshmp.gmm;

import static gov.usgs.earthquake.nshmp.gmm.Gmm.AM_09_INTERFACE_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.ASK_14_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.BCHYDRO_12_INTERFACE_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.BCHYDRO_12_SLAB_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.BSSA_14_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.CB_14_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.CY_14_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.ZHAO_06_INTERFACE_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Gmm.ZHAO_06_SLAB_BASIN;
import static gov.usgs.earthquake.nshmp.gmm.Imt.PGA;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA0P02;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA0P2;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA0P5;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA10P0;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA1P0;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA3P0;
import static gov.usgs.earthquake.nshmp.gmm.Imt.SA5P0;

import java.io.IOException;
import java.util.EnumSet;
import java.util.Set;
import java.util.stream.Stream;

import org.junit.jupiter.api.extension.ExtensionContext;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.ArgumentsProvider;
import org.junit.jupiter.params.provider.ArgumentsSource;

/**
 * Tests of 2018 NSHM GMMs that impose amplification-only basin effects.
 */
class DeepBasin implements ArgumentsProvider {

  private static String GMM_INPUTS = "/gmm/deep-basin-inputs.csv";
  private static String GMM_RESULTS = "/gmm/deep-basin-results.csv";

  @ParameterizedTest(name = "({index}) {0} {2} {1}")
  @ArgumentsSource(DeepBasin.class)
  void test(int index, Gmm gmm, Imt imt, double exMedian, double exSigma, String inputs) {
    GmmTest.test(index, gmm, imt, exMedian, exSigma, inputs);
  }

  @Override
  public Stream<? extends Arguments> provideArguments(ExtensionContext context) throws Exception {
    return GmmTest.loadResults(GMM_RESULTS, GMM_INPUTS);
  }

  /* Result generation sets */
  private static Set<Gmm> gmms = EnumSet.of(
      ASK_14_BASIN,
      BSSA_14_BASIN,
      CB_14_BASIN,
      CY_14_BASIN,
      AM_09_INTERFACE_BASIN,
      BCHYDRO_12_INTERFACE_BASIN,
      ZHAO_06_INTERFACE_BASIN,
      BCHYDRO_12_SLAB_BASIN,
      ZHAO_06_SLAB_BASIN);

  private static Set<Imt> imts = EnumSet.of(PGA, SA0P02, SA0P2, SA0P5, SA1P0, SA3P0, SA5P0, SA10P0);

  public static void main(String[] args) throws IOException {
    GmmTest.generateResults(gmms, imts, GMM_INPUTS, GMM_RESULTS);
  }

}
