package gov.usgs.earthquake.nshmp.internal;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.EnumSet;
import java.util.Map;
import java.util.Map.Entry;

import org.junit.jupiter.api.Test;

class UsRegionTests {

  static final EnumSet<UsRegion> TERRITORIES =
      EnumSet.of(UsRegion.AS, UsRegion.GU, UsRegion.MP, UsRegion.PR, UsRegion.VI);
  static final EnumSet<UsRegion> DISTRICTS = EnumSet.of(UsRegion.DC);
  static final EnumSet<UsRegion> OCONUS;
  static final Map<String, String> CAPITOLS =
      Map.of("Alaska", "Juneau", "Illinois", "Springfield", "Guam", "Hagåtña");

  static {
    EnumSet<UsRegion> oconus = EnumSet.copyOf(TERRITORIES);
    oconus.addAll(EnumSet.of(UsRegion.AK, UsRegion.HI));

    OCONUS = EnumSet.copyOf(oconus);
  }

  @Test
  final void testCapitol() {
    for (Entry<String, String> s : CAPITOLS.entrySet()) {
      assertEquals(s.getValue(), UsRegion.fromString(s.getKey()).get().capitol());
    }
  }

  @Test
  final void testFromString() {
    for (UsRegion region : UsRegion.values()) {
      assertEquals(region, UsRegion.fromString(region.toString()).get());
    }
  }

  @Test
  final void testDistricts() {
    assertEquals(DISTRICTS, UsRegion.districts());
  }

  @Test
  final void testTerritories() {
    assertEquals(TERRITORIES, UsRegion.territories());
  }

  @Test
  final void testStates() {
    EnumSet<UsRegion> others = EnumSet.copyOf(TERRITORIES);
    others.addAll(DISTRICTS);
    assertEquals(EnumSet.complementOf(others), UsRegion.states());
  }

  @Test
  final void testConterminous() {
    assertEquals(EnumSet.complementOf(OCONUS), UsRegion.conterminous());
  }

}
